@@ -1,3 +1,4 @@
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 /*!
  * @brief SSL Handling Routines
  *
@@ -5,21 +6,6 @@
  *
  * @author Copyright (C) 2011 Eivind Naess, 
  *      All Rights Reserved
- *
- * @par License:
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -158,8 +144,10 @@ static void sstp_operation_append(sstp_operation_st **head,
         return;
     }
 
-    while (ptr && ptr->next)
+    while (ptr->next)
+    {
         ptr = ptr->next;
+    }
 
     ptr->next = item;
 }
@@ -170,10 +158,10 @@ static void sstp_operation_append(sstp_operation_st **head,
 static void sstp_send_cont(int sock, short event, sstp_stream_st *ctx)
 {
     sstp_operation_st *op;
-    int ret = 0;
 
     while (ctx->send) 
     {
+        int ret;
         op = ctx->send;
         ctx->send = op->next;
 
@@ -279,14 +267,13 @@ static int sstp_operation_add_write(sstp_stream_st *ctx,
     void *arg)
 {
     sstp_operation_st *op = NULL;
-    int ret  = SSTP_FAIL;
     int pend = 0;
 
     op = sstp_operation_get(ctx, buf, timeout, complete, arg);
     if (!op) 
     {
         log_err("Could not allocate a free operation");
-        goto done;
+        return SSTP_FAIL;
     }
     
     sstp_operation_append(&ctx->send, op);
@@ -296,12 +283,13 @@ static int sstp_operation_add_write(sstp_stream_st *ctx,
             EV_WRITE | EV_TIMEOUT, NULL);
     if (pend)
     {
-        ret = SSTP_INPROG;
-        goto done;
+        return SSTP_INPROG;
     }
 
     if (timeout > 0)
+    {
         event |= EV_TIMEOUT;
+    }
 
     /* Configure the event */
     event_set(ctx->ev_send, ctx->ssock, event, 
@@ -311,15 +299,10 @@ static int sstp_operation_add_write(sstp_stream_st *ctx,
     event_base_set(ctx->ev_base, ctx->ev_send);
 
     /* Add the event */
-    ret = event_add(ctx->ev_send, (timeout > 0) ? 
+    event_add(ctx->ev_send, (timeout > 0) ? 
             &op->tout : NULL);
 
-    /* Success */
-    ret = SSTP_OKAY;
-
-done:
-
-    return ret;
+    return SSTP_OKAY;
 }
 
 status_t sstp_get_cert_hash(sstp_stream_st *ctx, int proto, 
@@ -417,17 +400,6 @@ done:
 }
 
 
-status_t sstp_last_activity(sstp_stream_st *stream, int seconds)
-{
-    if (difftime(time(NULL), stream->last) > seconds)
-    {
-        return SSTP_FAIL;
-    }
-
-    return SSTP_OKAY;
-}
-
-
 status_t sstp_stream_recv_plain(sstp_stream_st *ctx, sstp_buff_st *buf, 
         sstp_complete_fn complete, void *arg, int timeout)
 {
@@ -462,7 +434,6 @@ status_t sstp_stream_recv_http(sstp_stream_st *ctx, sstp_buff_st *buf,
 {
     status_t status = SSTP_FAIL;
     short event = 0;
-    int ret = 0;
 
     /* Setup the timeout */
     if (timeout > 0)
@@ -475,7 +446,7 @@ status_t sstp_stream_recv_http(sstp_stream_st *ctx, sstp_buff_st *buf,
 
     do {
         /* Try to read from the SSL socket until it blocks */
-        ret = SSL_read(ctx->ssl, buf->data + buf->off, buf->max - buf->off);
+        int ret = SSL_read(ctx->ssl, buf->data + buf->off, buf->max - buf->off);
         switch (SSL_get_error(ctx->ssl, ret))
         {
         case SSL_ERROR_NONE:
@@ -516,7 +487,6 @@ status_t sstp_stream_recv_sstp(sstp_stream_st *ctx, sstp_buff_st *buf,
         sstp_complete_fn complete, void *arg, int timeout)
 {
     status_t status = SSTP_FAIL;
-    int ret = 0;
 
     /* Activity Timer */
     ctx->last = time(NULL);
@@ -529,7 +499,7 @@ status_t sstp_stream_recv_sstp(sstp_stream_st *ctx, sstp_buff_st *buf,
             : 4 ;
 
         /* Try to read from the SSL socket */
-        ret = SSL_read(ctx->ssl, buf->data + buf->off, 
+        int ret = SSL_read(ctx->ssl, buf->data + buf->off,
                 buf->len - buf->off);
         switch (SSL_get_error(ctx->ssl, ret))
         {
@@ -654,8 +624,6 @@ status_t sstp_stream_send_plain(sstp_stream_st *stream, sstp_buff_st *buf,
 status_t sstp_stream_send(sstp_stream_st *stream, sstp_buff_st *buf,
     sstp_complete_fn complete, void *arg, int timeout)
 {
-    int ret = 0;
-
     stream->last = time(NULL);
     stream->send_cb = (event_fn) sstp_send_cont;
 
@@ -678,7 +646,7 @@ status_t sstp_stream_send(sstp_stream_st *stream, sstp_buff_st *buf,
     {
         /* Try SSL write to the socket */
         int err = 0;
-        ret = SSL_write(stream->ssl, buf->data + buf->off, 
+        int ret = SSL_write(stream->ssl, buf->data + buf->off,
                 buf->len - buf->off);
         switch ((err = SSL_get_error(stream->ssl, ret)))
         {
@@ -687,7 +655,7 @@ status_t sstp_stream_send(sstp_stream_st *stream, sstp_buff_st *buf,
             break;
 
         case SSL_ERROR_WANT_READ:
-            sstp_operation_add_write(stream, buf, EV_READ, 
+            sstp_operation_add_write(stream, buf, EV_READ,
                     timeout, complete, arg);
             return SSTP_INPROG;
         
@@ -718,7 +686,7 @@ static status_t sstp_stream_setup(sstp_stream_st *stream)
     stream->ssl = SSL_new(stream->ssl_ctx);
     if (stream->ssl == NULL)
     {
-        log_err("Could not create SSL session", -1);
+        log_err("Could not create SSL session");
         goto done;
     }
 
@@ -829,7 +797,7 @@ status_t sstp_stream_connect(sstp_stream_st *stream, struct sockaddr *addr,
     ret = sstp_set_sndbuf(stream->ssock, 32768);
     if (SSTP_OKAY != ret)      
     {                                              
-        log_warn("Unable to set send buffer size", errno);
+        log_warn("Unable to set send buffer size");
     }
 
     /* Connect to the server (non-blocking) */
